/******************************************************************************/
/*                                                                            */
/*                Advanced Navigation Packet Protocol Library                 */
/*                  Java Language Orientus SDK, Version 7.0                   */
/*                    Copyright 2023, Advanced Navigation                     */
/*                                                                            */
/******************************************************************************/
/*
 * Copyright (C) 2023 Advanced Navigation
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package com.advancednavigation.anPackets;

/* File Transfer Request */
public class ANPacket7
{
	public static final int HEADER_LENGTH = 14;

	// Data Encoding
	public static final int FILE_TRANSFER_ENCODING_BINARY = 0;
	public static final int FILE_TRANSFER_ENCODING_AES256 = 1;

	// Metadata
	public static final int FILE_TRANSFER_METADATA_NONE = 0;
	public static final int FILE_TRANSFER_METADATA_EXTENDED_ANPP = 1;
	public static final int FILE_TRANSFER_METADATA_UTF8_FILENAME = 2;
	public static final int FILE_TRANSFER_METADATA_AN_FIRMWARE = 3;

	public static final int AN_FIRMWARE_METADATA_SIZE = 48;
	public static final int AN_FIRMWARE_PAYLOAD_SIZE = 224;

	public long uniqueId;
	public long dataIndex;
	public long totalSize;
	public int dataEncoding;
	public int metadataType;
	public byte[] metadata;
	public byte[] packetData;

	public ANPacket7()
	{
		metadata = new byte[0];
		packetData = new byte[0];
	}

	public ANPacket toANPacket()
	{
		ANPacket packet = new ANPacket(HEADER_LENGTH + metadata.length + packetData.length, ANPacket.PACKET_ID_FILE_TRANSFER);
		TypeConversion.uint32ToBytes(packet.data, 0, uniqueId);
		TypeConversion.uint32ToBytes(packet.data, 4, dataIndex);
		TypeConversion.uint32ToBytes(packet.data, 8, totalSize);
		packet.data[12] = (byte) (dataEncoding & 0xFF);
		packet.data[13] = (byte) (metadataType & 0xFF);
		for (int i = 0; i < metadata.length; i++)
		{
			packet.data[HEADER_LENGTH + i] = metadata[i];
		}
		for (int i = 0; i < packetData.length; i++)
		{
			packet.data[HEADER_LENGTH + metadata.length + i] = packetData[i];
		}
		return packet;
	}
}
